/* Define if the C++ compiler supports BOOL */
#undef HAVE_BOOL

#undef VERSION

#undef PACKAGE

/* defines if having libgif (always 1) */
#undef HAVE_LIBGIF

/* defines if having libjpeg (always 1) */
#undef HAVE_LIBJPEG

/* defines which to take for ksize_t */
#undef ksize_t

/* define if you have setenv */
//#undef HAVE_FUNC_SETENV
#undef HAVE_SETENV
#undef HAVE_UNSETENV

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES    

/* Define if you need the GNU extensions to compile */
#undef _GNU_SOURCE

#ifndef HAVE_BOOL
#define HAVE_BOOL
typedef int bool;
const bool false = 0;
const bool true = 1;
#endif

/** Define to enable dmalloc */
#undef DMALLOC

/* Define if you want to disable test retriever */
#undef NTEST

/* Define if you want to enable workaround for KURLRequester problem */
#undef KURLREQ_ERR

/** base document type */
#undef DOC

/** document version */
#undef DOCVERS

/** enable kio retriever */
#undef ENABLE_KIO

/** check for kde with kapp revision >= 1.207 */
#undef KDE_VERSION_POST_1207

/** enable wget retriever */
#undef ENABLE_WGET
